export(benchmark_inter)
export(census_margins)
export(check_identifiability)
export(decompose_uncertainty)
export(fit_inter_sae)
export(identification_bounds)
export(inter_bootstrap)
export(inter_design)
export(inter_estimates)
export(inter_example)
export(inter_sensitivity)
export(margin_diagnostics)
export(simulate_inter_data)
S3method(plot,inter_sae)
S3method(print,census_margins)
S3method(print,inter_bootstrap)
S3method(print,inter_bounds)
S3method(print,inter_design)
S3method(print,inter_identifiability)
S3method(print,inter_sae)
S3method(print,summary_inter_sae)
S3method(summary,inter_sae)
